Deck

Struct Deck 

pub struct Deck<C: Copy + Clone + Debug + Ord + Display>(/* private fields */);
Standard card deck

Implementations

Source

impl<C: Copy + Clone + Debug + Ord + Display> Deck<C>

pub fn draw(&mut self) -> Result<C, DeckError>

Draw a card from the deck at random

Errors

Returns an error if the deck is out of cards

pub fn draw_random(&mut self) -> Result<C, DeckError>

Randomly draw a card

Errors

Errors if there are no cards to draw

pub fn draw_many_random(&mut self, count: usize) -> Vec<C>

Randomly draw up to cards, will stop early if out of cards This only shuffles the selected [count,len) range of cards For a mores random draw, use .shuffle() then .draw_many()

pub fn draw_many(&mut self, count: usize) -> Vec<C>

Draw up to cards, will stop early if out of cards

pub fn draw_rest(&mut self) -> Vec<C>

Draw the rest of the cards

pub fn draw_rest_random(&mut self) -> Vec<C>

Randomly draw the rest of the cards

pub fn insert(&mut self, card: C)

Insert a card into the deck

pub fn into_vec(self) -> Vec<C>

Convert the dec into a vector of cards

pub fn shuffle(&mut self)

Shuffle the deck

pub fn peek(&self) -> Option<&C>

Peek at the next card

pub fn from_cards(cards: Vec<C>) -> Self

Create a new deck of cards

pub fn is_empty(&self) -> bool

Check if the deck is empty

pub fn len(&self) -> usize

Length of the cards in the deck

pub fn empty() -> Self

Create an empty deck of cards