Solitaire

Struct Solitaire 

pub struct Solitaire {
    pub stockpile: Deck<StandardCard>,
    pub waste: Vec<StandardCard>,
    pub tablue: [Vec<SolitaireCard>; 7],
    pub foundation: [Vec<SolitaireCard>; 4],
    /* private fields */
}
Solitaire

Fields

stockpile: Deck<StandardCard>

stockpile of cards

waste: Vec<StandardCard>

Waste pile

tablue: [Vec<SolitaireCard>; 7]

Table

foundation: [Vec<SolitaireCard>; 4]

Foundation pile

Implementations

Source

impl Solitaire

pub fn new() -> Self

New solitaire game

pub fn draw_card(&mut self) -> SError<StandardCard>

Move a card from stockpile to waste pile, if stockpile is empty, move waste to stockpile and draw card

Errors

Errors if there is no more cards to draw Can also error if moves exceed u32

pub fn moves(&self) -> u32

Number of moves performed

pub fn peek(&self) -> SError<StandardCard>

Peek at the next card

Errors

Errors if there is no cards to peek at from either the stockpile or waste

pub fn move_to(&mut self, target: Area, destination: Area) -> SError<()>

Move card(s) from target -> Destination

Errors

First Check phase: /// Target rules:

  • Foundation
    • The row must be less than 4
  • Stockpile
    • Waste must not be empty
    • Stockpile must not be empty
  • Waste
    • Waste must not be empty
  • Tablue
    • Row must be less than 7
    • The requested amount must be less than or equal to the number of faceup cards
    • The tablue must be all faceup if requested amount is 0 (All)

Destination:

  • Foundation
    • Row less than 4
  • Tablue
    • Row less than 7
  • Stockpile OR Waste
    • Always ok

Second Phase:

Target Stockpile:

  • Stockpile (Not Allowed)
  • Waste
    • Failed to draw from stockpile
  • Foundation
    • Card(s) not allowed to be stacked (Solitaire Rules)
  • Tablue
    • Card(s) not allowed to be stacked (Solitaire Rules)

Target Waste:

  • Stockpile (Never allowed)
  • Waste (Never allowed)
  • Foundation
    • Card(s) not allowed to be stacked (Solitaire Rules)
  • Tablue
    • Card(s) not allowed to be stacked (Solitaire Rules)

Target Tablue:

  • Stockpile (Never allowed)
  • Waste (Never allowed)
  • Tablue
    • Card(s) not allowed to be stacked (Solitaire Rules)
  • Foundation
    • Card(s) not allowed to be stacked (Solitaire Rules)

Target Foundation:

  • Waste (Never allowed)
  • Stockpile (Never allowed)
  • Foundation (Never allowed)
  • Tablue
    • Card(s) not allowed to be stacked (Solitaire Rules)

Can also error if moves exceed the max of u32

pub fn game_won(&self) -> bool

Check if the solitaire game is a win